@@ -39,7 +39,6 @@
 #'
 #' @export
 
-
 transect_inventory <- function(data_set) {
   if (!is.data.frame(data_set)) {
     stop(
@@ -78,7 +77,7 @@ transect_inventory <- function(data_set) {
   data_set <-
     mutate(data_set, across(tidyselect::where(is.character), ~ na_if(.x, "")))
 
-  data_set <- data_set |> select(1:13)
+  data_set <- data_set[1:13]
 
   start_row <-
     1 + which(data_set$V1 == "Species Relative Importance Values:")
@@ -90,11 +89,16 @@ transect_inventory <- function(data_set) {
 
   dropped <- data_set[start_row:end_row,]
 
-  colnames(dropped) <- lapply(dropped[1,], as.character)
+  colnames(dropped) <- lapply(dropped[1,],
+                              as.character)
   dropped <- dropped[-1,]
 
-  suppressWarnings(new <- dropped |>
-                     mutate(across(c(5:6, 9:13), as.double)))
+  dropped_problematic <- dropped |>
+    dplyr::filter(!(.data$Species == "Bare ground"|.data$Species == "Water"))
+
+  suppressWarnings(new <- dropped_problematic |>
+                     mutate(across(c(5:6, 9:13),
+                                   as.double)))
 
   class(new) <- c("tbl_df", "tbl", "data.frame")
 
